@@ -2,7 +2,7 @@
 /*
  * MIT License
  *
- * Copyright (c) 2014-2024 Patrizio Bekerle -- <patrizio@bekerle.com>
+ * Copyright (c) 2014-2025 Patrizio Bekerle -- <patrizio@bekerle.com>
  * Copyright (c) 2019-2021 Waqar Ahmed      -- <waqar.17a@gmail.com>
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -175,7 +175,8 @@ void MarkdownHighlighter::initHighlightingRules() {
         rule.shouldContain = QStringLiteral("|");
         // Support up to 3 leading spaces, because md4c seems to support it
         // See https://github.com/pbek/QOwnNotes/issues/3137
-        rule.pattern = QRegularExpression(QStringLiteral("^\\s{0,3}(\\|.+?\\|)$"));
+        rule.pattern =
+            QRegularExpression(QStringLiteral("^\\s{0,3}(\\|.+?\\|)$"));
         rule.capturingGroup = 1;
         _highlightingRules.append(rule);
     }
