@@ -1196,7 +1196,8 @@ OwnCloudService *OwnCloudService::instance(bool reset, int cloudConnectionId) {
 void OwnCloudService::handleVersionsLoading(QString data) {
 #ifndef INTEGRATION_TESTS
     MainWindow::instance()->enableShowVersionsButton();
-    MainWindow::instance()->showStatusBarMessage(tr("Done with loading note versions"), 2000);
+    MainWindow::instance()->showStatusBarMessage(tr("Done with loading note versions"),
+                                                 QStringLiteral("🕒"), 2000);
 #endif
 
     // check if we get any data at all
@@ -1255,7 +1256,8 @@ void OwnCloudService::handleVersionsLoading(QString data) {
 void OwnCloudService::handleTrashedLoading(QString data) {
 #ifndef INTEGRATION_TESTS
     MainWindow::instance()->enableShowTrashButton();
-    MainWindow::instance()->showStatusBarMessage(tr("Done with loading trashed notes"), 2000);
+    MainWindow::instance()->showStatusBarMessage(tr("Done with loading trashed notes"),
+                                                 QStringLiteral("🗑️"), 2000);
 #endif
 
     // check if we get any data at all
