@@ -1,6 +1,7 @@
 #include "notesubfoldertree.h"
 
 #include <QHeaderView>
+#include <QKeyEvent>
 #include <QMenu>
 #include <memory>
 
@@ -17,7 +18,7 @@ NoteSubFolderTree::NoteSubFolderTree(QWidget *parent) : QTreeWidget(parent) {
         header()->setSectionResizeMode(1, QHeaderView::ResizeToContents);
     });
     setContextMenuPolicy(Qt::CustomContextMenu);
-
+    installEventFilter(this);
     initConnections();
 }
 
@@ -349,7 +350,8 @@ void NoteSubFolderTree::removeSelectedNoteSubFolders(QTreeWidget *parent) {
             // remove the directory recursively from the file system
             if (noteSubFolder.removeFromFileSystem()) {
                 mainWindow->showStatusBarMessage(
-                    tr("Removed note subfolder: %1").arg(noteSubFolder.fullPath()));
+                    tr("Removed note subfolder: %1").arg(noteSubFolder.fullPath()),
+                    QStringLiteral("📁"));
             }
         }
 
@@ -428,3 +430,16 @@ void NoteSubFolderTree::onItemSelectionChanged() {
         Q_EMIT multipleSubfoldersSelected();
     }
 }
+
+bool NoteSubFolderTree::eventFilter(QObject *obj, QEvent *event) {
+    if (event->type() == QEvent::KeyPress) {
+        auto *keyEvent = dynamic_cast<QKeyEvent *>(event);
+
+        if ((keyEvent->key() == Qt::Key_Delete) || (keyEvent->key() == Qt::Key_Backspace)) {
+            removeSelectedNoteSubFolders(this);
+            return true;
+        }
+    }
+
+    return QTreeWidget::eventFilter(obj, event);
+}
